<?php
/*
Plugin Name: DrawBlog
Plugin URI: http://drawblog.com/
Description: A WordPress plugin that allows commenters to draw a picture.
Version: 0.61
Author: Randy Tayler
Author URI: http://randytayler.com
License: GPL

*/
global $drawblog_db_version;
global $drawblog_form_complete;
$drawblog_db_version = "0.62";
/* Runs when plugin is activated */
register_activation_hook(__FILE__,'drawblog_install'); 
/* Runs on plugin deactivation*/
// removing this call, because I don't think people necessarily want to delete all 
// their images when deactivating the plugin
//register_deactivation_hook( __FILE__, 'drawblog_remove' );

add_filter('comment_text', 'drawblog_add_image_to_comment');
add_action('comment_form', 'drawblog_comment_form');
add_action('comment_post', 'drawblog_save_image');

function drawblog_install() {
	global $drawblog_db_version;
	add_option("drawblog_db_version", $drawblog_db_version);
	add_option("drawblog_directory", '/wp-content/plugins/drawblog/images/');
	add_option("drawblog_canvas_title", __('Click here to draw a picture to include in your comment.'));
	add_option("drawblog_canvas_width", 400);
	add_option("drawblog_canvas_height", 300);
}
function drawblog_remove() {
	global $wpdb;	
	// delete the comments drawings' data from the database
	$sql = "DELETE FROM ".$wpdb->prefix."options WHERE option_name = 'drawblog_db_version' OR option_name = 'drawblog_directory'";
	$wpdb->query($sql);
	
	$sql = "DELETE FROM ".$wpdb->prefix."commentmeta WHERE meta_key='drawblog_image'";
	$wpdb->query($sql);
}
function drawblog_add_image_to_comment($comment_text){
	global $comment; 
	$drawblog_image = drawblog_get_image($comment->comment_ID);
	if (($drawblog_image) && 
		(is_file(ABSPATH . get_option('drawblog_directory') . $drawblog_image)) && 
		(getimagesize( ABSPATH . get_option('drawblog_directory') . $drawblog_image) !== false)){			
			$comment_text = "<img src=\"".get_option('drawblog_directory').$drawblog_image."\" class=\"drawblogimage\"><br>".$comment_text;
	}
	return $comment_text;
}
function drawblog_get_image($comment_id){
	global $wpdb;
	$meta = get_comment_meta($comment_id, 'drawblog_image');
	return $meta[0];
}
function drawblog_comment_form(){
	global $drawblog_form_complete;
	if (!$drawblog_form_complete){
		echo drawblog_add_canvas();
		$drawblog_form_complete = true;
	}
}
function drawblog_save_image($comment_id){
	global $wpdb;
	if ($_POST['drawblog_include_pic'] == true){
		$data = $_POST['drawblog_picture'];
		$raw_data = str_replace(' ','+',$data);
		$filtered_data=substr($raw_data, strpos($raw_data, ",")+1);
		$data = base64_decode($filtered_data);
		$new_image = uniqid($comment_id.'_').'.png';
		$fp = fopen(ABSPATH . get_option('drawblog_directory').$new_image, 'wb' );
		fwrite( $fp, $data);
		fclose( $fp );
		if (is_file(ABSPATH . "wp-content/plugins/drawblog/icons/dbwm.png")){
			$im = imagecreatefrompng(ABSPATH . get_option('drawblog_directory').$new_image);
			$src = imagecreatefrompng(ABSPATH ."wp-content/plugins/drawblog/icons/dbwm.png");
			list($wm_width, $wm_height) = getimagesize(ABSPATH ."wp-content/plugins/drawblog/icons/dbwm.png");
			imagecopy($im, $src, get_option('drawblog_canvas_width')-$wm_width, get_option('drawblog_canvas_height') - $wm_height, 0, 0, $wm_width, $wm_height);
			imagepng($im, ABSPATH . get_option('drawblog_directory').$new_image);
		} else {
			echo "File not found.";die();
		}
		add_comment_meta($comment_id, 'drawblog_image', $new_image);
	}
}
function drawblog_add_canvas(){
	if (get_option('drawblog_api_key')!=''){
		$ch = curl_init('http://drawblog.com/auth.php');
		curl_setopt($ch, CURLOPT_POST, true);
		$postfields = 'apikey='.get_option('drawblog_api_key').'&domain='.$_SERVER['HTTP_HOST'];
		if (get_option('drawblog_send_theme')) $postfields .='&theme='.get_stylesheet();
		curl_setopt($ch, CURLOPT_POSTFIELDS, $postfields);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		echo curl_exec($ch);
		curl_close($ch);
	}
	$width = get_option('drawblog_canvas_width');
	$height = get_option('drawblog_canvas_height');
	include "drawblog_canvas.php";
}

function drawblog_determine_classname(){
	$themedir = get_stylesheet_directory();
	$theme = get_stylesheet(); // I wish this function was called get_theme(), but whatever
	switch ($theme){
		case 'inferno-mf':
			$postclass = 'post';
			break;
		case 'easel':
		case 'eclipse':
		case 'ifeature':
			$postclass = 'entry';
			break;
		case 'responsive':
			$postclass = "post-entry";
			break;
		case 'mantra':
		case 'pagelines':
		case 'pinboard':
		case 'twentyeleven':
		case 'twentyten':
		case 'twentytwelve':
		default:
			$postclass = "entry-content";
			break;
	}
	return $postclass;
}

if ( is_admin() ){
	add_action('admin_menu', 'drawblog_admin_menu');
	
	function drawblog_admin_menu() {
		add_options_page('DrawBlog', 'DrawBlog', 'administrator', 'drawblog', 'drawblog_settings_page');
	}
	function drawblog_update_options($values){
		$directory = $values['drawblog_directory'];	
		$title = $values['drawblog_canvas_title'];		
		$width = intval($values['drawblog_canvas_width']);
		$height = intval($values['drawblog_canvas_height']);
		if ($width<=0) return __('Canvas width'); //returns other than 'success', below, indicate a field with an error. Canvases cannot be negative or zero values.
		if ($height<=0) return __('Canvas height');
		update_option('drawblog_api_key', $values['drawblog_api_key']);
		update_option('drawblog_directory', $directory);		
		update_option('drawblog_canvas_width', $width);		
		update_option('drawblog_canvas_height', $height);
		update_option('drawblog_canvas_title', $title);				
		update_option('post_class_name', $values['post_class_name']);
		return 'success';
	}
	function drawblog_settings_page() {
		include "drawblog_admin.php";
	}
}
?>